@@ -4,10 +4,11 @@
 #include <errno.h>
 #include <glib.h>
 #include <gpiod.h>
+#include <gpiod-test.h>
+#include <gpiod-test-common.h>
+#include <gpiosim-glib.h>
 
-#include "gpiod-test.h"
-#include "gpiod-test-helpers.h"
-#include "gpiod-test-sim.h"
+#include "helpers.h"
 
 #define GPIOD_TEST_GROUP "chip-info"
 
@@ -18,7 +19,7 @@ GPIOD_TEST_CASE(get_chip_info_name)
 	g_autoptr(struct_gpiod_chip_info) info = NULL;
 
 	chip = gpiod_test_open_chip_or_fail(g_gpiosim_chip_get_dev_path(sim));
-	info = gpiod_test_get_chip_info_or_fail(chip);
+	info = gpiod_test_chip_get_info_or_fail(chip);
 
 	g_assert_cmpstr(gpiod_chip_info_get_name(info), ==,
 			g_gpiosim_chip_get_name(sim));
@@ -32,7 +33,7 @@ GPIOD_TEST_CASE(get_chip_info_label)
 	g_autoptr(struct_gpiod_chip_info) info = NULL;
 
 	chip = gpiod_test_open_chip_or_fail(g_gpiosim_chip_get_dev_path(sim));
-	info = gpiod_test_get_chip_info_or_fail(chip);
+	info = gpiod_test_chip_get_info_or_fail(chip);
 
 	g_assert_cmpstr(gpiod_chip_info_get_label(info), ==, "foobar");
 }
@@ -44,7 +45,7 @@ GPIOD_TEST_CASE(get_num_lines)
 	g_autoptr(struct_gpiod_chip_info) info = NULL;
 
 	chip = gpiod_test_open_chip_or_fail(g_gpiosim_chip_get_dev_path(sim));
-	info = gpiod_test_get_chip_info_or_fail(chip);
+	info = gpiod_test_chip_get_info_or_fail(chip);
 
 	g_assert_cmpuint(gpiod_chip_info_get_num_lines(info), ==, 16);
 }
